@@ -18,10 +18,6 @@ import {
   activateRSPDisplayVersionExtension,
 } from "./displayversion"
 
-import {
-  activateRSPQueryExtension,
-} from "./query"
-
 import {
   activateRSPSavequitExtension,
 } from "./savequit"
@@ -34,9 +30,6 @@ function activateRSPExtension(app: JupyterFrontEnd, mainMenu: IMainMenu, docMana
   console.log('...activating displayversion extension...');
   activateRSPDisplayVersionExtension(app, statusBar);
   console.log('...activated...')
-  console.log('...activating query extension...');
-  activateRSPQueryExtension(app, mainMenu, docManager);
-  console.log('...activated...')
   console.log('...activating savequit extension...');
   activateRSPSavequitExtension(app, mainMenu, docManager);
   console.log('...activated...')
